@@ -58,26 +58,26 @@ _gss_asn1_length_der (size_t len, unsigned char *ans, size_t * ans_len)
     }
 }
 
-static unsigned long
-_gss_asn1_get_length_der (const unsigned char *der, int *len)
+static size_t
+_gss_asn1_get_length_der (const char *der, int *len)
 {
-  unsigned long ans;
+  size_t ans;
   int k, punt;
 
   if (!(der[0] & 128))
     {
       /* short form */
       *len = 1;
-      return der[0];
+      return (unsigned char) der[0];
     }
   else
     {
       /* Long form */
-      k = der[0] & 0x7F;
+      k = (unsigned char) der[0] & 0x7F;
       punt = 1;
       ans = 0;
       while (punt <= k && punt < *len)
-	ans = ans * 256 + der[punt++];
+	ans = ans * 256 + (unsigned char) der[punt++];
 
       *len = punt;
       return ans;
@@ -85,12 +85,13 @@ _gss_asn1_get_length_der (const unsigned char *der, int *len)
 }
 
 static int
-_gss_encapsulate_token (char *oid, size_t oidlen,
-			char *in, size_t inlen, char **out, size_t * outlen)
+_gss_encapsulate_token (const char *oid, size_t oidlen,
+			const char *in, size_t inlen,
+			void **out, size_t * outlen)
 {
   size_t oidlenlen;
   size_t asn1len, asn1lenlen;
-  char *p;
+  unsigned char *p;
 
   _gss_asn1_length_der (oidlen, NULL, &oidlenlen);
   asn1len = 1 + oidlenlen + oidlen + inlen;
@@ -114,7 +115,7 @@ _gss_encapsulate_token (char *oid, size_t oidlen,
 }
 
 int
-gss_encapsulate_token (gss_buffer_t input_message,
+gss_encapsulate_token (const gss_buffer_t input_message,
 		       gss_OID token_oid, gss_buffer_t output_message)
 {
   return _gss_encapsulate_token (token_oid->elements,
@@ -126,8 +127,8 @@ gss_encapsulate_token (gss_buffer_t input_message,
 }
 
 int
-gss_encapsulate_token_prefix (gss_buffer_t input_message,
-			      char *prefix, size_t prefixlen,
+gss_encapsulate_token_prefix (const gss_buffer_t input_message,
+			      const char *prefix, size_t prefixlen,
 			      gss_OID token_oid, gss_buffer_t output_message)
 {
   char *in;
@@ -152,7 +153,7 @@ gss_encapsulate_token_prefix (gss_buffer_t input_message,
 }
 
 static int
-_gss_decapsulate_token (char *in, size_t inlen,
+_gss_decapsulate_token (const char *in, size_t inlen,
 			char **oid, size_t * oidlen,
 			char **out, size_t * outlen)
 {
@@ -192,68 +193,35 @@ _gss_decapsulate_token (char *in, size_t inlen,
     return 0;
 
   *oidlen = asn1lenlen;
-  *oid = xmalloc (*oidlen);
-  memcpy (*oid, in, *oidlen);
+  *oid = in;
 
   inlen -= asn1lenlen;
   in += asn1lenlen;
 
   *outlen = inlen;
-  *out = xmalloc (*outlen);
-  memcpy (*out, in, *outlen);
+  *out = in;
 
   return 1;
 }
 
 int
-gss_decapsulate_token (gss_buffer_t input_message,
-		       gss_OID token_oid, gss_buffer_t output_message)
+gss_decapsulate_token (const gss_buffer_t input_message,
+		       const gss_OID token_oid,
+		       char **dataptr, size_t *datalen)
 {
-  char *oid, *out;
-  size_t oidlen, outlen;
+  char *oid;
+  size_t oidlen;
   int rc;
 
   rc = _gss_decapsulate_token (input_message->value,
 			       input_message->length,
-			       &oid, &oidlen, &out, &outlen);
+			       &oid, &oidlen, dataptr, datalen);
   if (!rc)
     return 0;
 
-  token_oid->length = oidlen;
-  token_oid->elements = (void *) oid;
-
-  output_message->length = outlen;
-  output_message->value = (void *) out;
-
-  return 1;
-}
-
-int
-gss_decapsulate_token_check (gss_buffer_t input_message,
-			     char *prefix, size_t prefixlen,
-			     gss_OID token_oid, gss_buffer_t output_message)
-{
-  gss_OID_desc tmp;
-  gss_buffer_desc data;
-  int rc;
-
-  rc = gss_decapsulate_token (input_message, &tmp, &data);
-  if (!rc)
+  if (oidlen != token_oid->length ||
+      memcmp (oid, token_oid->elements, oidlen) != 0)
     return 0;
 
-  if (!gss_oid_equal (&tmp, token_oid) ||
-      data.length < prefixlen || memcmp (data.value, prefix, prefixlen) != 0)
-    {
-      gss_release_oid (NULL, &tmp);
-      gss_release_buffer (NULL, &data);
-      return 0;
-    }
-
-  memmove (data.value, (char *) data.value + prefixlen,
-	   data.length - prefixlen);
-
-  output_message->length = data.length - prefixlen;
-  output_message->value = data.value;
-
   return 1;
 }
