@@ -1,4 +1,4 @@
-/* error.c	Error handling functionality.
+/* error.c --- Error handling functionality.
  * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
@@ -19,7 +19,20 @@
  *
  */
 
-#include "internal.h"
+/* Get i18n. */
+#include <gettext.h>
+#define _(String) dgettext (PACKAGE, String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
+/* Get strlen. */
+#include <string.h>
+
+/* Get xmalloc etc. */
+#include "xalloc.h"
+
+/* _gss_find_mech */
+#include "meta.h"
 
 struct gss_status_codes
 {
@@ -306,20 +319,3 @@ gss_display_status (OM_uint32 * minor_status,
 
   return GSS_S_COMPLETE;
 }
-
-/* For va_list, va_start, va_end. */
-#include <stdarg.h>
-
-void
-gss_warn (const char *format, ...)
-{
-  va_list ap;
-
-  va_start (ap, format);
-
-  fprintf (stderr, "%s: ", PACKAGE);
-  vfprintf (stderr, format, ap);
-  fprintf (stderr, "\n");
-
-  va_end (ap);
-}
